# dbt-oracle

[![PyPI version](https://badge.fury.io/py/dbt-oracle.svg)](https://pypi.python.org/pypi/dbt-oracle)
[![dbt-tests-adapter](https://github.com/oracle/dbt-oracle/actions/workflows/oracle-xe-adapter-tests.yml/badge.svg)](https://github.com/oracle/dbt-oracle/actions/workflows/oracle-xe-adapter-tests.yml)

dbt "adapters" are responsible for adapting dbt's functionality to a given database. `dbt-oracle` implements dbt functionalities for the Oracle database. 

> Prior to version 1.0.0, dbt-oracle was created and maintained by [Indicium](https://indicium.tech/) on [their GitHub repo](https://github.com/techindicium/dbt-oracle). Contributors in this repo are credited for laying the groundwork and maintaining the adapter till version 0.4.3.
From version 1.0.0, dbt-oracle is maintained and distributed by Oracle.


For dbt documentation, refer https://docs.getdbt.com/docs/introduction

## Installation

For installation, read how you can set up [Oracle profile][1] for dbt

## Sample project

To get started, a sample dbt project can be found in the directory [/dbt_adbs_test_project][5]

## Contributing <a name='contributing'></a>
This project welcomes contributions from the community. Before submitting a pull request, please review our [contribution guide][2].

## Security <a name='security'></a>
Please consult the [security guide][3] for our responsible security vulnerability disclosure process.

## License <a name='license'></a>
dbt-oracle is licensed under Apache 2.0 License which you can find [here][4]

[1]: https://docs.getdbt.com/reference/warehouse-profiles/oracle-profile
[2]: https://github.com/oracle/dbt-oracle/blob/main/CONTRIBUTING.md
[3]: https://github.com/oracle/dbt-oracle/blob/main/SECURITY.md
[4]: https://github.com/oracle/dbt-oracle/blob/main/LICENSE.txt
[5]: https://github.com/oracle/dbt-oracle/tree/main/dbt_adbs_test_project
